==> mono_1.1.17.1.orig.tar.gz: mono-1.1.17.1/mcs/class/System/System.ComponentModel/RunWorkerCompletedEventArgs.cs <==
//
// RunWorkerCompletedEventArgs.cs
//
// Author:
//	Atsushi Enomoto <atsushi@ximian.com>
//
// Copyright (C) 2006 Novell, Inc.
//

//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if NET_2_0

namespace System.ComponentModel
{
	public class RunWorkerCompletedEventArgs : AsyncCompletedEventArgs
	{
		// LAMESPEC: there is no way to provide UserState. See also:
		// http://pluralsight.com/blogs/mike/archive/2005/10/21/15783.aspx
		public RunWorkerCompletedEventArgs (
			object result, Exception error, bool cancelled)
			: base (error, cancelled, null)
		{
			this.result = result;
		}

		object result, user_state;

		public object Result {
			get { return result; }
		}

		// It is always null. See .ctor() for details.
		[Browsable (false)]
		[EditorBrowsable (EditorBrowsableState.Never)]
		public object UserState {
			get { return user_state; }
		}
	}
}

#endif

==> mono_1.9.1+dfsg.orig.tar.gz: mono-1.9.1+dfsg/mcs/class/System/System.ComponentModel/RunWorkerCompletedEventArgs.cs <==
//
// RunWorkerCompletedEventArgs.cs
//
// Author:
//	Atsushi Enomoto <atsushi@ximian.com>
//
// Copyright (C) 2006 Novell, Inc.
//

//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if NET_2_0

namespace System.ComponentModel
{
	public class RunWorkerCompletedEventArgs : AsyncCompletedEventArgs
	{
		// LAMESPEC: there is no way to provide UserState. See also:
		// http://pluralsight.com/blogs/mike/archive/2005/10/21/15783.aspx
		public RunWorkerCompletedEventArgs (
			object result, Exception error, bool cancelled)
			: base (error, cancelled, null)
		{
			this.result = result;
		}

		object result, user_state;

		public object Result {
			get { return result; }
		}

		// It is always null. See .ctor() for details.
		[Browsable (false)]
		[EditorBrowsable (EditorBrowsableState.Never)]
		public new object UserState {
			get { return user_state; }
		}
	}
}

#endif
